# needed for site_reference_configs.autodiscover test

raise TypeError("the earth is not round?")
